==> apache-camel-3.4.2-src.zip: apache-camel-3.4.2/components/camel-mina/src/test/java/org/apache/camel/component/mina/MinaSpringMultipleUDPTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.mina;

import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.spring.CamelSpringTestSupport;
import org.junit.Test;
import org.springframework.context.support.AbstractApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

/**
 *
 */
public class MinaSpringMultipleUDPTest extends CamelSpringTestSupport {

    @Override
    protected AbstractApplicationContext createApplicationContext() {
        return new ClassPathXmlApplicationContext(
            "org/apache/camel/component/mina/SpringMultipleUDPTest-context.xml");
    }

    @Test
    public void testMinaSpringProtobufEndpoint() throws Exception {
        MockEndpoint result = getMockEndpoint("mock:result");
        result.expectedMessageCount(7);

        for (int i = 0; i < 7; i++) {
            template.requestBody("myMinaEndpoint", "Hello World" + i + LS);
        }

        // Sleep for awhile to let the messages go through.
        Thread.sleep(3000);

        assertMockEndpointsSatisfied();
    }
}

==> apache-camel-3.10.0-src.zip: apache-camel-3.10.0/components/camel-mina/src/test/java/org/apache/camel/component/mina/MinaSpringMultipleUDPTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.mina;

import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.spring.junit5.CamelSpringTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.AbstractApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

/**
 *
 */
public class MinaSpringMultipleUDPTest extends CamelSpringTestSupport {

    private static final String LS = System.lineSeparator();

    @Override
    protected AbstractApplicationContext createApplicationContext() {
        return new ClassPathXmlApplicationContext(
                "org/apache/camel/component/mina/SpringMultipleUDPTest-context.xml");
    }

    @Test
    public void testMinaSpringProtobufEndpoint() throws Exception {
        MockEndpoint result = getMockEndpoint("mock:result");
        result.expectedMessageCount(7);

        for (int i = 0; i < 7; i++) {
            template.requestBody("myMinaEndpoint", "Hello World" + i + LS);
        }

        // Sleep for awhile to let the messages go through.
        Thread.sleep(3000);

        assertMockEndpointsSatisfied();
    }
}
